var Cufflinks = function()
{
	var cufflinks = {};
	var debug = 0;
	
	var JOB_IMAGE = { 'DONE': 'ok.png', 'ERROR': 'error.png'};
	var rawBioAssays;
	
	// Page initialization
	cufflinks.initPage = function()
	{
		
		// Step 1

		// Navigation
		Buttons.addClickHandler('gocancel', Wizard.cancelWizard);
		Buttons.addClickHandler('gorestart', Wizard.restartWizard);
		Buttons.addClickHandler('gonext', Wizard.goNextOnClick);
		Buttons.addClickHandler('goregister', Wizard.goRegister);
			
		// Final registration
		Events.addEventHandler('wizard', 'wizard-submit', cufflinks.submit);

		Wizard.showLoadingAnimation('Loading bioassays...');
		var url = '../Cufflinks.servlet?ID='+App.getSessionId();
		url += '&cmd=GetUnconfirmed';
		Wizard.asyncJsonRequest(url, cufflinks.initializeStep1);
	}
	
	// --- Step 1 -----------------------------------
	cufflinks.initializeStep1 = function(response)
	{
		rawBioAssays = response.rawBioAssays;
		if (rawBioAssays.length == 0)
		{
			Wizard.setFatalError('No raw bioassays available for processing.');
			return;
		}
		
		var html = '<table id="rawBioAssaysTable">';
		html += '<thead>';
		// Header row
		html += '<tr>';
		html += '<th></th>';
		html += '<th class="dottedleft"></th>';
		html += '<th class="dottedleft"></th>';
		html += '<th class="dottedleft" colspan="2">Jobs</th>'
		html += '<th class="dottedleft"></th>';
		html += '<th class="dottedleft" colspan="3">Actions</th>';
		html += '<th class="dottedleft">Comment</th>';
		html += '</tr>';
		
		html += '<tr>';
		html += '<th>Library</th>';
		html += '<th class="dottedleft">Plate</th>';
		html += '<th class="dottedleft">Count</th>';
		html += '<th class="dottedleft">Cufflinks</th>'
		html += '<th>Import</th>';
		html += '<th class="dottedleft">Files</th>';
		html += '<th class="dottedleft">Flag RNA</th>';
		html += '<th>Re-run</th>';
		html += '<th>Confirm</th>';
		html += '<th class="dottedleft"></th>';
		html += '</tr>';
		html += '</thead>';
		html += '<tbody>';
		var numWithError = 0;
		for (var rawNo = 0; rawNo < rawBioAssays.length; rawNo++)
		{
			var raw = rawBioAssays[rawNo];

			var lib = raw.lib;
			lib.stratagene = Reggie.isStratagene(lib.name);
			lib.external = Reggie.isExternal(lib.name);
			var libPlate = lib.bioWell.bioPlate;
			
			var cufflinksJob = raw.cufflinksJob;
			var importJob = raw.importJob;
			var isError = false;
	
			html += '<tr class="highlight ' + (rawNo % 4 < 2 ? 'evenrow' : 'oddrow') + '">';
			html += '<td class="prompt">'+Strings.encodeTags(raw.name)+'</td>';
			html += '<td class="dottedleft">'+Strings.encodeTags(libPlate.name)+'</td>';
			html += '<td class="dottedleft">'+raw.spots+'</td>';

			html += '<td class="dottedleft">';
			if (cufflinksJob)
			{
				isError |= cufflinksJob.status == 'ERROR';
				html += '<span class="link item-link" data-item-type="JOB" data-item-id="'+cufflinksJob.id+'" title="'+Strings.encodeTags(cufflinksJob.statusMessage)+'"><img src="../images/'+JOB_IMAGE[cufflinksJob.status]+'"></span>';
			}
			html += '</td>';
			html += '<td>';
			if (importJob)
			{
				isError |= importJob.status == 'ERROR';
				html += '<span class="link item-link" data-item-type="JOB" data-item-id="'+importJob.id+'" title="'+Strings.encodeTags(importJob.statusMessage)+'"><img src="../images/'+JOB_IMAGE[importJob.status]+'"></span>';
			}
			html += '</td>';
			if (raw.DataFilesFolder && cufflinksJob && cufflinksJob.server)
			{
				html += '<td class="dottedleft">';
				html += '<span class="link file-link" data-server="'+Strings.encodeTags(cufflinksJob.server)+'" data-folder="'+Strings.encodeTags(raw.DataFilesFolder)+'" data-item-id="'+raw.id+'" title="View generated files"><img src="../images/remote_folder.png"></span>';
				html += '</td>';
			}
			else
			{
				html += '<td class="dottedleft">-</td>';
			}
			// Do not allow flagging external or stratagene
			var confirmChecked = raw.spots > 0 ? ' checked' : '';
			var reRunChecked = isError ? ' checked' : '';
			var confirmDisabled = isError ? ' disabled' : '';
			if (isError) numWithError++;
			
			if (lib.stratagene || lib.external)
			{
				html += '<td class="dottedleft">-</td>';
			}
			else
			{
				html += '<td class="dottedleft"><input type="checkbox" name="flag.'+raw.id+'"></td>';
			}
			
			html += '<td><input type="checkbox" name="rerun.'+raw.id+'"'+reRunChecked+'></td>';
			html += '<td><input type="checkbox" name="confirm.'+raw.id+'"'+confirmChecked+confirmDisabled+'></td>';
			html += '<td class="dottedleft comment"><input type="text" name="comment.'+raw.id+'"></td>';
			html += '</tr>';

		}
		html += '</tbody>';
		html += '</table>';
		Doc.element('rawBioAssays').innerHTML = html;
		if (numWithError > 0) Doc.show('delete-items', 'table');
		
		// Add click handler to items
		var clickableItems = document.getElementsByClassName('item-link');
		for (var i = 0; i < clickableItems.length; i++)
		{
			Events.addEventHandler(clickableItems[i], 'click', Items.itemOnClick);
		}
		
		// Add click handler to file links
		var clickableItems = document.getElementsByClassName('file-link');
		for (var i = 0; i < clickableItems.length; i++)
		{
			Events.addEventHandler(clickableItems[i], 'click', cufflinks.fileLinkOnClick);
		}

		Doc.show('step-1');
		Doc.show('goregister');
	}
	
	cufflinks.fileLinkOnClick = function(event)
	{
		var folder = Data.get(event.currentTarget, 'folder');
		var server = Data.get(event.currentTarget, 'server');
		var itemId = Data.get(event.currentTarget, 'item-id');
		server = server.replace(/\s*\[.*\]/, '');
		var url = 'view_remote_files.jsp?ID=' + App.getSessionId();
		url += '&clusterId='+server;
		url += '&path='+encodeURIComponent(folder);
		url += '&itemType=RAWBIOASSAY&itemId='+itemId;
		Dialogs.openPopup(url, 'ViewProjectFiles', 750, 500);
	}
	
	
	cufflinks.submit = function()
	{
		var frm = document.forms['reggie'];
		var submitInfo = {};
		submitInfo.deleteItemsCreatedByFailedJobs = frm.deleteItemsCreatedByFailedJobs.checked;
		
		var all = [];
		submitInfo.rawBioAssays = all;
		for (var rawNo = 0; rawNo < rawBioAssays.length; rawNo++)
		{
			var raw = rawBioAssays[rawNo];
			var tmp = {};
			tmp.id = raw.id;
			
			tmp.flag = frm['flag.'+raw.id] && frm['flag.'+raw.id].checked;
			tmp.rerun = frm['rerun.'+raw.id].checked;
			tmp.confirm = frm['confirm.'+raw.id].checked;
			tmp.comment = frm['comment.'+raw.id].value;
			
			all[all.length] = tmp;
		}
		
		var url = '../Cufflinks.servlet?ID='+App.getSessionId();
		url += '&cmd=RegisterCufflinks';
		Wizard.showLoadingAnimation('Performing registration...');
		Wizard.asyncJsonRequest(url, cufflinks.submissionResults, 'POST', JSON.stringify(submitInfo));
	}
	
	cufflinks.submissionResults = function(response)
	{
		Wizard.showFinalMessage(response.messages);
		Doc.show('gorestart');
	}
	
	
	return cufflinks;
}();

Doc.onLoad(Cufflinks.initPage);

